# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class UploadUserCertificateRequest(DaraModel):
    def __init__(
        self,
        cert: str = None,
        encrypt_cert: str = None,
        encrypt_private_key: str = None,
        key: str = None,
        name: str = None,
        resource_group_id: str = None,
        sign_cert: str = None,
        sign_private_key: str = None,
        tags: List[main_models.UploadUserCertificateRequestTags] = None,
    ):
        # The content of the certificate in the PEM format.
        self.cert = cert
        # The content of the encryption certificate in PEM format.
        self.encrypt_cert = encrypt_cert
        # The private key of the encryption certificate in the PEM format.
        self.encrypt_private_key = encrypt_private_key
        # The private key of the certificate in the PEM format.
        self.key = key
        # The name of the certificate. The name can be up to 64 characters in length, and can contain all types of characters, such as letters, digits, and underscores (_).
        # 
        # >  The name must be unique within an Alibaba Cloud account.
        # 
        # This parameter is required.
        self.name = name
        # the resource group id.
        self.resource_group_id = resource_group_id
        # The content of the signing certificate in the PEM format.
        self.sign_cert = sign_cert
        # The private key of the signing certificate in the PEM format.
        self.sign_private_key = sign_private_key
        # The tags.
        self.tags = tags

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert is not None:
            result['Cert'] = self.cert

        if self.encrypt_cert is not None:
            result['EncryptCert'] = self.encrypt_cert

        if self.encrypt_private_key is not None:
            result['EncryptPrivateKey'] = self.encrypt_private_key

        if self.key is not None:
            result['Key'] = self.key

        if self.name is not None:
            result['Name'] = self.name

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.sign_cert is not None:
            result['SignCert'] = self.sign_cert

        if self.sign_private_key is not None:
            result['SignPrivateKey'] = self.sign_private_key

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Cert') is not None:
            self.cert = m.get('Cert')

        if m.get('EncryptCert') is not None:
            self.encrypt_cert = m.get('EncryptCert')

        if m.get('EncryptPrivateKey') is not None:
            self.encrypt_private_key = m.get('EncryptPrivateKey')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('SignCert') is not None:
            self.sign_cert = m.get('SignCert')

        if m.get('SignPrivateKey') is not None:
            self.sign_private_key = m.get('SignPrivateKey')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.UploadUserCertificateRequestTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class UploadUserCertificateRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key.
        self.key = key
        # The tag value.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListCertWarehouseRequest(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        instance_id: str = None,
        name: str = None,
        show_size: int = None,
        type: str = None,
    ):
        # The number of the page to return. Default value: 1.
        self.current_page = current_page
        # The instance ID of the certificate application repository.
        self.instance_id = instance_id
        # The name of the certificate application repository. Fuzzy match is supported.
        self.name = name
        # The number of entries to return on each page. Default value: 50.
        self.show_size = show_size
        # The type of the certificate application repository. Valid values:
        # 
        # *   **ssl**: certificate application repository of SSL certificates
        # *   **uploadPCA**: certificate application repository of uploaded private certificates
        # *   **free**: certificate application repository of free certificates, available only on the China site (aliyun.com)
        # *   **aliyunPCA**: certificate application repository of private certificates purchased from Alibaba Cloud Private Certificate Authority (PCA), available only on the China site (aliyun.com)
        # *   **disable**: disabled certificate application repository
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.name is not None:
            result['Name'] = self.name

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListInstancesRequest(DaraModel):
    def __init__(
        self,
        brand: str = None,
        certificate_status: str = None,
        certificate_type: str = None,
        current_page: int = None,
        instance_type: str = None,
        keyword: str = None,
        resource_group_id: str = None,
        show_size: int = None,
        status: str = None,
    ):
        self.brand = brand
        self.certificate_status = certificate_status
        self.certificate_type = certificate_type
        self.current_page = current_page
        self.instance_type = instance_type
        self.keyword = keyword
        self.resource_group_id = resource_group_id
        self.show_size = show_size
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.brand is not None:
            result['Brand'] = self.brand

        if self.certificate_status is not None:
            result['CertificateStatus'] = self.certificate_status

        if self.certificate_type is not None:
            result['CertificateType'] = self.certificate_type

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.instance_type is not None:
            result['InstanceType'] = self.instance_type

        if self.keyword is not None:
            result['Keyword'] = self.keyword

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Brand') is not None:
            self.brand = m.get('Brand')

        if m.get('CertificateStatus') is not None:
            self.certificate_status = m.get('CertificateStatus')

        if m.get('CertificateType') is not None:
            self.certificate_type = m.get('CertificateType')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('InstanceType') is not None:
            self.instance_type = m.get('InstanceType')

        if m.get('Keyword') is not None:
            self.keyword = m.get('Keyword')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateCsrRequest(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        common_name: str = None,
        corp_name: str = None,
        country_code: str = None,
        department: str = None,
        key_size: int = None,
        locality: str = None,
        name: str = None,
        province: str = None,
        sans: str = None,
    ):
        # The algorithm. Valid values: RSA, SM2, and ECC. For more information about algorithms, see [Select an SSL certificate](https://help.aliyun.com/document_detail/197871.html).
        # 
        # This parameter is required.
        self.algorithm = algorithm
        # The primary domain name, which is a common name.
        # 
        # This parameter is required.
        self.common_name = common_name
        # The name of the company.
        self.corp_name = corp_name
        # The code of the country or region in which the organization is located. For example, you can use CN to indicate China and use US to indicate the United States.
        # 
        # This parameter is required.
        self.country_code = country_code
        # The department that uses the certificate.
        self.department = department
        # The key length that is used by the algorithm.
        # 
        # *   The key length for RSA algorithms can be 2,048, 3,072, and 4,096 bits.
        # *   The key length for ECC and SM2 algorithms can be 256 bits.
        # 
        # This parameter is required.
        self.key_size = key_size
        # The city where the company is located.
        # 
        # This parameter is required.
        self.locality = locality
        # The name of the CSR. The name can be up to 50 characters in length and can contain letters, digits, underscores (_), hyphens (-), and periods (.).
        self.name = name
        # The province or location where the company is located.
        # 
        # This parameter is required.
        self.province = province
        # The secondary domain names. Separate multiple domain names with commas (,). You can use the CSR to apply for a certificate for both the primary and secondary domain names.
        self.sans = sans

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.corp_name is not None:
            result['CorpName'] = self.corp_name

        if self.country_code is not None:
            result['CountryCode'] = self.country_code

        if self.department is not None:
            result['Department'] = self.department

        if self.key_size is not None:
            result['KeySize'] = self.key_size

        if self.locality is not None:
            result['Locality'] = self.locality

        if self.name is not None:
            result['Name'] = self.name

        if self.province is not None:
            result['Province'] = self.province

        if self.sans is not None:
            result['Sans'] = self.sans

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('CorpName') is not None:
            self.corp_name = m.get('CorpName')

        if m.get('CountryCode') is not None:
            self.country_code = m.get('CountryCode')

        if m.get('Department') is not None:
            self.department = m.get('Department')

        if m.get('KeySize') is not None:
            self.key_size = m.get('KeySize')

        if m.get('Locality') is not None:
            self.locality = m.get('Locality')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Province') is not None:
            self.province = m.get('Province')

        if m.get('Sans') is not None:
            self.sans = m.get('Sans')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListCsrResponseBody(DaraModel):
    def __init__(
        self,
        csr_list: List[main_models.ListCsrResponseBodyCsrList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        # The CSRs.
        self.csr_list = csr_list
        # The page number.
        self.current_page = current_page
        # The request ID.
        self.request_id = request_id
        # The number of entries per page. Default value: 50.
        self.show_size = show_size
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.csr_list:
            for v1 in self.csr_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['CsrList'] = []
        if self.csr_list is not None:
            for k1 in self.csr_list:
                result['CsrList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.csr_list = []
        if m.get('CsrList') is not None:
            for k1 in m.get('CsrList'):
                temp_model = main_models.ListCsrResponseBodyCsrList()
                self.csr_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListCsrResponseBodyCsrList(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        common_name: str = None,
        corp_name: str = None,
        country_code: str = None,
        csr_id: int = None,
        department: str = None,
        has_private_key: bool = None,
        key_sha_2: str = None,
        key_size: int = None,
        locality: str = None,
        name: str = None,
        province: str = None,
        sans: str = None,
    ):
        # The algorithm. Valid values: RSA, SM2, and ECC.
        self.algorithm = algorithm
        # The primary domain name, which is a common name.
        self.common_name = common_name
        # The name of the company.
        self.corp_name = corp_name
        # The code of the country or region in which the organization is located. For example, you can use CN to indicate China and use US to indicate the United States. The default value is the code of the country or region in which the organization is located. The organization is associated with the intermediate CA certificate from which the certificate is issued. For more information about country codes, see the "Country codes" section of the [Manage company profiles](https://help.aliyun.com/document_detail/198289.html) topic.
        self.country_code = country_code
        # The ID of the CSR.
        self.csr_id = csr_id
        # The department that uses the certificate.
        self.department = department
        # Indicates whether the certificate contains a private key.
        self.has_private_key = has_private_key
        # The public key that is calculated by using the SHA256 algorithm.
        self.key_sha_2 = key_sha_2
        # The key length that is used by the algorithm. The key length for RSA algorithms can be 2,048, 3,072, and 4,096 bits. The key length for ECC and SM2 algorithms can be 256 bits.
        self.key_size = key_size
        # The city where the company is located.
        self.locality = locality
        # The name of the CSR.
        self.name = name
        # The province or location.
        self.province = province
        # The secondary domain names. Separate multiple domain names with commas (,).
        self.sans = sans

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.corp_name is not None:
            result['CorpName'] = self.corp_name

        if self.country_code is not None:
            result['CountryCode'] = self.country_code

        if self.csr_id is not None:
            result['CsrId'] = self.csr_id

        if self.department is not None:
            result['Department'] = self.department

        if self.has_private_key is not None:
            result['HasPrivateKey'] = self.has_private_key

        if self.key_sha_2 is not None:
            result['KeySha2'] = self.key_sha_2

        if self.key_size is not None:
            result['KeySize'] = self.key_size

        if self.locality is not None:
            result['Locality'] = self.locality

        if self.name is not None:
            result['Name'] = self.name

        if self.province is not None:
            result['Province'] = self.province

        if self.sans is not None:
            result['Sans'] = self.sans

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('CorpName') is not None:
            self.corp_name = m.get('CorpName')

        if m.get('CountryCode') is not None:
            self.country_code = m.get('CountryCode')

        if m.get('CsrId') is not None:
            self.csr_id = m.get('CsrId')

        if m.get('Department') is not None:
            self.department = m.get('Department')

        if m.get('HasPrivateKey') is not None:
            self.has_private_key = m.get('HasPrivateKey')

        if m.get('KeySha2') is not None:
            self.key_sha_2 = m.get('KeySha2')

        if m.get('KeySize') is not None:
            self.key_size = m.get('KeySize')

        if m.get('Locality') is not None:
            self.locality = m.get('Locality')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Province') is not None:
            self.province = m.get('Province')

        if m.get('Sans') is not None:
            self.sans = m.get('Sans')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListContactResponseBody(DaraModel):
    def __init__(
        self,
        contact_list: List[main_models.ListContactResponseBodyContactList] = None,
        current_page: int = None,
        keyword: str = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        # The contacts.
        self.contact_list = contact_list
        # The page number. Default value: **1**.
        self.current_page = current_page
        # The keyword used in the fuzzy search.
        self.keyword = keyword
        # The request ID.
        self.request_id = request_id
        # The number of certificates per page. Default value: **20**.
        self.show_size = show_size
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.contact_list:
            for v1 in self.contact_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['ContactList'] = []
        if self.contact_list is not None:
            for k1 in self.contact_list:
                result['ContactList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.keyword is not None:
            result['Keyword'] = self.keyword

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.contact_list = []
        if m.get('ContactList') is not None:
            for k1 in m.get('ContactList'):
                temp_model = main_models.ListContactResponseBodyContactList()
                self.contact_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('Keyword') is not None:
            self.keyword = m.get('Keyword')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListContactResponseBodyContactList(DaraModel):
    def __init__(
        self,
        contact_id: int = None,
        email: str = None,
        email_status: int = None,
        mobile: str = None,
        mobile_status: int = None,
        name: str = None,
        webhooks: str = None,
    ):
        # The ID of the contact.
        self.contact_id = contact_id
        # The email address of the contact.
        self.email = email
        # Indicates whether the email address passed the verification.
        self.email_status = email_status
        # The phone number.
        self.mobile = mobile
        # Indicates whether the phone number was verified.
        self.mobile_status = mobile_status
        # The name of the contact.
        self.name = name
        # The webhook URL of the chatbot.
        self.webhooks = webhooks

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.contact_id is not None:
            result['ContactId'] = self.contact_id

        if self.email is not None:
            result['Email'] = self.email

        if self.email_status is not None:
            result['EmailStatus'] = self.email_status

        if self.mobile is not None:
            result['Mobile'] = self.mobile

        if self.mobile_status is not None:
            result['MobileStatus'] = self.mobile_status

        if self.name is not None:
            result['Name'] = self.name

        if self.webhooks is not None:
            result['Webhooks'] = self.webhooks

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ContactId') is not None:
            self.contact_id = m.get('ContactId')

        if m.get('Email') is not None:
            self.email = m.get('Email')

        if m.get('EmailStatus') is not None:
            self.email_status = m.get('EmailStatus')

        if m.get('Mobile') is not None:
            self.mobile = m.get('Mobile')

        if m.get('MobileStatus') is not None:
            self.mobile_status = m.get('MobileStatus')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Webhooks') is not None:
            self.webhooks = m.get('Webhooks')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListDeploymentJobRequest(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        job_type: str = None,
        show_size: int = None,
        status: str = None,
    ):
        # The page number. Default value: 1.
        self.current_page = current_page
        # The type of the deployment task.
        # 
        # Valid values:
        # 
        # *   cloud: multi-cloud deployment task.
        # *   user: cloud service deployment task. This type of task does not support Elastic Compute Service (ECS) instances.
        self.job_type = job_type
        # The number of certificates per page. Default value: **50**.
        self.show_size = show_size
        # The status of the deployment task.
        # 
        # Valid values:
        # 
        # *   success
        # *   pending
        # *   scheduling
        # *   processing
        # *   error
        # *   editing
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.job_type is not None:
            result['JobType'] = self.job_type

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('JobType') is not None:
            self.job_type = m.get('JobType')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateDeploymentJobRequest(DaraModel):
    def __init__(
        self,
        cert_ids: str = None,
        contact_ids: str = None,
        job_id: int = None,
        name: str = None,
        resource_ids: str = None,
        schedule_time: int = None,
    ):
        # The ID of the certificate. Separate multiple certificate IDs with commas (,). You can call the [ListUserCertificateOrder](https://help.aliyun.com/document_detail/455804.html) operation to obtain the ID of a certificate from the **CertificateId** parameter.
        self.cert_ids = cert_ids
        # The ID of the contact. Separate multiple contact IDs with commas (,). You can call the [ListContact](https://help.aliyun.com/document_detail/2712221.html) operation to obtain the ID of a contact from the **ContactId** parameter.
        self.contact_ids = contact_ids
        # The ID of the deployment task. You can call the [CreateDeploymentJob](https://help.aliyun.com/document_detail/2712234.html) operation to obtain the ID of a deployment task from the JobId parameter. You can also call the [ListDeploymentJob](https://help.aliyun.com/document_detail/2712223.html) operation to obtain the ID of a deployment task.
        # 
        # This parameter is required.
        self.job_id = job_id
        # The name of the deployment task.
        self.name = name
        # The ID of the cloud resource. Separate multiple resource IDs with commas (,). You can call the [ListCloudResources](https://help.aliyun.com/document_detail/2712230.html) operation to obtain the ID of a cloud resource from the **Id** parameter.
        self.resource_ids = resource_ids
        # The time when the task starts. The value is a UNIX timestamp. If you do not specify this parameter, the system immediately starts the task after it is created.
        self.schedule_time = schedule_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_ids is not None:
            result['CertIds'] = self.cert_ids

        if self.contact_ids is not None:
            result['ContactIds'] = self.contact_ids

        if self.job_id is not None:
            result['JobId'] = self.job_id

        if self.name is not None:
            result['Name'] = self.name

        if self.resource_ids is not None:
            result['ResourceIds'] = self.resource_ids

        if self.schedule_time is not None:
            result['ScheduleTime'] = self.schedule_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertIds') is not None:
            self.cert_ids = m.get('CertIds')

        if m.get('ContactIds') is not None:
            self.contact_ids = m.get('ContactIds')

        if m.get('JobId') is not None:
            self.job_id = m.get('JobId')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('ResourceIds') is not None:
            self.resource_ids = m.get('ResourceIds')

        if m.get('ScheduleTime') is not None:
            self.schedule_time = m.get('ScheduleTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateCsrResponseBody(DaraModel):
    def __init__(
        self,
        csr: str = None,
        csr_id: int = None,
        request_id: str = None,
    ):
        # The content of the CSR.
        self.csr = csr
        # The unique identifier of the CSR. You can use this value to obtain the content of the CSR. For more information about the operation that you can call to obtain the content of a CSR, see [GetCsrDetail](https://help.aliyun.com/document_detail/2709720.html).
        self.csr_id = csr_id
        # The request ID.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.csr is not None:
            result['Csr'] = self.csr

        if self.csr_id is not None:
            result['CsrId'] = self.csr_id

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('CsrId') is not None:
            self.csr_id = m.get('CsrId')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListContactRequest(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        keyword: str = None,
        show_size: int = None,
    ):
        # The page number. Default value: 1.
        self.current_page = current_page
        # The keyword used in the query. For example, you can specify a keyword in names, email addresses, and mobile phone numbers.
        self.keyword = keyword
        # The number of contacts per page.
        self.show_size = show_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.keyword is not None:
            result['Keyword'] = self.keyword

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('Keyword') is not None:
            self.keyword = m.get('Keyword')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListUserCertificateOrderRequest(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        keyword: str = None,
        order_type: str = None,
        resource_group_id: str = None,
        show_size: int = None,
        status: str = None,
    ):
        # The number of the page to return.
        self.current_page = current_page
        # The domain name that is bound or the ID of the resource. Fuzzy match is supported.
        self.keyword = keyword
        # The type of the order. Default value: **CPACK**. Valid values:
        # 
        # *   **CPACK**: virtual resource order. If you set OrderType to CPACK, only the information about orders that are generated to consume the certificate quota is returned.
        # *   **BUY**: purchase order. If you set OrderType to BUY, only the information about purchase orders is returned. In most cases, this type of order can be ignored.
        # *   **UPLOAD**: uploaded certificate. If you set OrderType to UPLOAD, only uploaded certificates are returned.
        # *   **CERT**: certificate. If you set OrderType to CERT, both issued certificates and uploaded certificates are returned.
        self.order_type = order_type
        # The ID of the resource group. You can call the [ListResources](https://help.aliyun.com/document_detail/2716559.html) operation to obtain the ID.
        self.resource_group_id = resource_group_id
        # The number of entries to return on each page. Default value: 50.
        self.show_size = show_size
        # The certificate status of the order. Valid values:
        # 
        # *   **PAYED**: pending application. You can set Status to PAYED only if you set OrderType to CPACK or BUY.
        # *   **CHECKING**: validating. You can set Status to CHECKING only if you set OrderType to CPACK or BUY.
        # *   **CHECKED_FAIL**: validation failed. You can set Status to CHECKED_FAIL only if you set OrderType to CPACK or BUY.
        # *   **ISSUED**: issued.
        # *   **WILLEXPIRED**: about to expire.
        # *   **EXPIRED**: expired.
        # *   **NOTACTIVATED**: not activated. You can set Status to NOTACTIVATED only if you set OrderType to CPACK or BUY.
        # *   **REVOKED**: revoked. You can set Status to REVOKED only if you set OrderType to CPACK or BUY.
        # 
        # If you set OrderType to CERT or UPLOAD and Status is left empty, valid certificates are returned by default, including issued certificates and certificates that are about to expire. If you set OrderType to CPACK or BUY and Status is left empty, all orders are returned by default.
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.keyword is not None:
            result['Keyword'] = self.keyword

        if self.order_type is not None:
            result['OrderType'] = self.order_type

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('Keyword') is not None:
            self.keyword = m.get('Keyword')

        if m.get('OrderType') is not None:
            self.order_type = m.get('OrderType')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class DescribeDeploymentJobStatusResponseBody(DaraModel):
    def __init__(
        self,
        buy_count: int = None,
        cert_count: int = None,
        cost_count: int = None,
        failed_count: int = None,
        match_worker_count: int = None,
        product_worker_count: List[main_models.DescribeDeploymentJobStatusResponseBodyProductWorkerCount] = None,
        request_id: str = None,
        resource_count: int = None,
        rollback_count: int = None,
        rollback_failed_count: int = None,
        rollback_success_count: int = None,
        success_count: int = None,
        use_count: int = None,
        worker_count: int = None,
    ):
        # The total number of purchased resources.
        self.buy_count = buy_count
        # The number of certificates involved in the deployment task.
        self.cert_count = cert_count
        # The number of resources consumed by worker tasks.
        self.cost_count = cost_count
        # The number of failed worker tasks, excluding rollback tasks.
        self.failed_count = failed_count
        # The total number of worker tasks that match the certificate.
        self.match_worker_count = match_worker_count
        # The number of cloud resources to which certificates are deployed in the deployment task.
        self.product_worker_count = product_worker_count
        # The request ID.
        self.request_id = request_id
        # The total number of resources.
        self.resource_count = resource_count
        # The number of worker tasks that are rolled backed.
        self.rollback_count = rollback_count
        # The number of worker tasks that failed to be rolled back.
        self.rollback_failed_count = rollback_failed_count
        # The number of worker tasks that are successfully rolled back.
        self.rollback_success_count = rollback_success_count
        # The number of successful worker tasks, excluding rollback tasks.
        self.success_count = success_count
        # The total number of used resources.
        self.use_count = use_count
        # The total number of resources to which certificate are deployed in the current cloud service. The value indicates the total number of worker tasks.
        self.worker_count = worker_count

    def validate(self):
        if self.product_worker_count:
            for v1 in self.product_worker_count:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.buy_count is not None:
            result['BuyCount'] = self.buy_count

        if self.cert_count is not None:
            result['CertCount'] = self.cert_count

        if self.cost_count is not None:
            result['CostCount'] = self.cost_count

        if self.failed_count is not None:
            result['FailedCount'] = self.failed_count

        if self.match_worker_count is not None:
            result['MatchWorkerCount'] = self.match_worker_count

        result['ProductWorkerCount'] = []
        if self.product_worker_count is not None:
            for k1 in self.product_worker_count:
                result['ProductWorkerCount'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.resource_count is not None:
            result['ResourceCount'] = self.resource_count

        if self.rollback_count is not None:
            result['RollbackCount'] = self.rollback_count

        if self.rollback_failed_count is not None:
            result['RollbackFailedCount'] = self.rollback_failed_count

        if self.rollback_success_count is not None:
            result['RollbackSuccessCount'] = self.rollback_success_count

        if self.success_count is not None:
            result['SuccessCount'] = self.success_count

        if self.use_count is not None:
            result['UseCount'] = self.use_count

        if self.worker_count is not None:
            result['WorkerCount'] = self.worker_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BuyCount') is not None:
            self.buy_count = m.get('BuyCount')

        if m.get('CertCount') is not None:
            self.cert_count = m.get('CertCount')

        if m.get('CostCount') is not None:
            self.cost_count = m.get('CostCount')

        if m.get('FailedCount') is not None:
            self.failed_count = m.get('FailedCount')

        if m.get('MatchWorkerCount') is not None:
            self.match_worker_count = m.get('MatchWorkerCount')

        self.product_worker_count = []
        if m.get('ProductWorkerCount') is not None:
            for k1 in m.get('ProductWorkerCount'):
                temp_model = main_models.DescribeDeploymentJobStatusResponseBodyProductWorkerCount()
                self.product_worker_count.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResourceCount') is not None:
            self.resource_count = m.get('ResourceCount')

        if m.get('RollbackCount') is not None:
            self.rollback_count = m.get('RollbackCount')

        if m.get('RollbackFailedCount') is not None:
            self.rollback_failed_count = m.get('RollbackFailedCount')

        if m.get('RollbackSuccessCount') is not None:
            self.rollback_success_count = m.get('RollbackSuccessCount')

        if m.get('SuccessCount') is not None:
            self.success_count = m.get('SuccessCount')

        if m.get('UseCount') is not None:
            self.use_count = m.get('UseCount')

        if m.get('WorkerCount') is not None:
            self.worker_count = m.get('WorkerCount')

        return self

class DescribeDeploymentJobStatusResponseBodyProductWorkerCount(DaraModel):
    def __init__(
        self,
        count: int = None,
        product_name: str = None,
    ):
        # The total number of resources of a cloud service in the deployment task.
        self.count = count
        # The name of the cloud service. Valid values:
        # 
        # *   **SLB**: Classic Load Balancer (CLB). This value is supported only at the China site (aliyun.com).
        # *   **LIVE**: ApsaraVideo Live. This value is supported only at the China site (aliyun.com).
        # *   **webHosting**: Cloud Web Hosting. This value is supported only at the China site (aliyun.com).
        # *   **VOD**: ApsaraVideo VOD. This value is supported only at the China site (aliyun.com).
        # *   **CR**: Container Registry. This value is supported only at the China site (aliyun.com).
        # *   **DCDN**: Dynamic Content Delivery Network (DCDN).
        # *   **DDOS**: Anti-DDoS.
        # *   **CDN**: Alibaba Cloud CDN (CDN).
        # *   **ALB**: Application Load Balancer (ALB).
        # *   **APIGateway**: API Gateway.
        # *   **FC**: Function Compute.
        # *   **GA**: Global Accelerator (GA).
        # *   **MSE**: Microservices Engine (MSE).
        # *   **NLB**: Network Load Balancer (NLB).
        # *   **OSS**: Object Storage Service (OSS).
        # *   **SAE**: Serverless App Engine (SAE).
        # *   **TencentCDN**: Tencent Cloud Content Delivery Network (CDN).
        # *   **WAF**: Web Application Firewall (WAF).
        self.product_name = product_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['Count'] = self.count

        if self.product_name is not None:
            result['ProductName'] = self.product_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('ProductName') is not None:
            self.product_name = m.get('ProductName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListCsrRequest(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        current_page: int = None,
        key_word: str = None,
        show_size: int = None,
    ):
        # The algorithm. Valid values: RSA, ECC, and SM2.
        self.algorithm = algorithm
        # The page number.
        self.current_page = current_page
        # The keyword.
        self.key_word = key_word
        # The number of entries per page. Default value: 50.
        self.show_size = show_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.key_word is not None:
            result['KeyWord'] = self.key_word

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('KeyWord') is not None:
            self.key_word = m.get('KeyWord')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListCertResponseBody(DaraModel):
    def __init__(
        self,
        cert_list: List[main_models.ListCertResponseBodyCertList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        # An array that consists of the certificates.
        self.cert_list = cert_list
        # The page number of the returned page. Default value: 1.
        self.current_page = current_page
        # The ID of the request.
        self.request_id = request_id
        # The number of entries returned per page. Default value: 50.
        self.show_size = show_size
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.cert_list:
            for v1 in self.cert_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['CertList'] = []
        if self.cert_list is not None:
            for k1 in self.cert_list:
                result['CertList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.cert_list = []
        if m.get('CertList') is not None:
            for k1 in m.get('CertList'):
                temp_model = main_models.ListCertResponseBodyCertList()
                self.cert_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListCertResponseBodyCertList(DaraModel):
    def __init__(
        self,
        after_date: int = None,
        before_date: int = None,
        cert_type: str = None,
        common_name: str = None,
        exist_private_key: bool = None,
        identifier: str = None,
        issuer: str = None,
        sans: str = None,
        source_type: str = None,
        status: str = None,
        wh_id: int = None,
        wh_instance_id: str = None,
    ):
        # The expiration time of the certificate. The value is a UNIX timestamp. Unit: milliseconds.
        self.after_date = after_date
        # The issuance time of the certificate. The value is a UNIX timestamp. Unit: milliseconds.
        self.before_date = before_date
        # 证书的类型 。取值：
        # 
        # - **CA**：表示CA证书。
        # - **CERT**：表示签发的证书。
        self.cert_type = cert_type
        # The domain name.
        self.common_name = common_name
        # Indicates whether the certificate contains a private key. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.exist_private_key = exist_private_key
        # The unique identifier of the certificate.
        self.identifier = identifier
        # The issuer of the certificate.
        self.issuer = issuer
        # The domain names that are bound to the certificate. Multiple domain names are separated by commas.
        self.sans = sans
        # The source of the certificate. Valid values:
        # 
        # *   **upload**: uploaded certificate
        # *   **aliyun**: Alibaba Cloud certificate
        self.source_type = source_type
        # The status of the certificate. Valid values:
        # 
        # *   **ISSUE**: issued
        # *   **REVOKE**: revoked
        self.status = status
        # The ID of the certificate repository.
        self.wh_id = wh_id
        # The instance ID of the certificate repository.
        self.wh_instance_id = wh_instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.after_date is not None:
            result['AfterDate'] = self.after_date

        if self.before_date is not None:
            result['BeforeDate'] = self.before_date

        if self.cert_type is not None:
            result['CertType'] = self.cert_type

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.exist_private_key is not None:
            result['ExistPrivateKey'] = self.exist_private_key

        if self.identifier is not None:
            result['Identifier'] = self.identifier

        if self.issuer is not None:
            result['Issuer'] = self.issuer

        if self.sans is not None:
            result['Sans'] = self.sans

        if self.source_type is not None:
            result['SourceType'] = self.source_type

        if self.status is not None:
            result['Status'] = self.status

        if self.wh_id is not None:
            result['WhId'] = self.wh_id

        if self.wh_instance_id is not None:
            result['WhInstanceId'] = self.wh_instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AfterDate') is not None:
            self.after_date = m.get('AfterDate')

        if m.get('BeforeDate') is not None:
            self.before_date = m.get('BeforeDate')

        if m.get('CertType') is not None:
            self.cert_type = m.get('CertType')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('ExistPrivateKey') is not None:
            self.exist_private_key = m.get('ExistPrivateKey')

        if m.get('Identifier') is not None:
            self.identifier = m.get('Identifier')

        if m.get('Issuer') is not None:
            self.issuer = m.get('Issuer')

        if m.get('Sans') is not None:
            self.sans = m.get('Sans')

        if m.get('SourceType') is not None:
            self.source_type = m.get('SourceType')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('WhId') is not None:
            self.wh_id = m.get('WhId')

        if m.get('WhInstanceId') is not None:
            self.wh_instance_id = m.get('WhInstanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateDeploymentJobStatusRequest(DaraModel):
    def __init__(
        self,
        job_id: int = None,
        status: str = None,
    ):
        # The ID of the deployment task.
        # 
        # This parameter is required.
        self.job_id = job_id
        # The desired status.
        # 
        # Valid values:
        # 
        # *   pending
        # *   scheduling
        # *   editing
        # 
        # This parameter is required.
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.job_id is not None:
            result['JobId'] = self.job_id

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('JobId') is not None:
            self.job_id = m.get('JobId')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class VerifyRequest(DaraModel):
    def __init__(
        self,
        cert_identifier: str = None,
        custom_identifier: str = None,
        message: str = None,
        message_type: str = None,
        signature_value: str = None,
        signing_algorithm: str = None,
        warehouse_id: str = None,
    ):
        # The unique identifier of the certificate. You can call the [ListCert](https://help.aliyun.com/document_detail/455806.html) operation to obtain the unique identifier of a certificate.
        # 
        # *   If the certificate is an SSL certificate, the value of this parameter must be in the {Certificate ID}-cn-hangzhou format.
        # *   If the certificate is a private certificate, the value of this parameter must be the value of the Identifier field for the private certificate.
        self.cert_identifier = cert_identifier
        self.custom_identifier = custom_identifier
        # The data for which you want to verify the signature. The value must be encoded in Base64.\\
        # For example, if the hexadecimal data that you want to verify is [0x31, 0x32, 0x33, 0x34], set the parameter to the Base64-encoded value MTIzNA==. If you set MessageType to RAW, the size of the data must be less than 4 KB. If the size of the data is greater than 4 KB, you can set MessageType to DIGEST and set Message to the digest of the data. The digest is also called hash value. You can compute the digest of the data on an on-premises machine. The certificate repository uses your certificate application system to compute the message digest. The message digest algorithm that is used must meet the requirements of the specified signature algorithm. The following signature algorithms require different message digest algorithms:
        # 
        # *   If the signature algorithm is SHA256withRSA, SHA256withRSA/PSS, or SHA256withECDSA, the message digest algorithm must be SHA-256.
        # *   If the signature algorithm is SM3withSM2, the message digest algorithm must be SM3.
        # 
        # This parameter is required.
        self.message = message
        # The value type of the Message parameter. Valid values:
        # 
        # *   **RAW**: the raw data. This is the default value.
        # *   **DIGEST**: the message digest of the raw data.
        # 
        # This parameter is required.
        self.message_type = message_type
        # The signature value. The value must be encoded in Base64.
        # 
        # This parameter is required.
        self.signature_value = signature_value
        # The signature algorithm. Valid values:
        # 
        # *   **SHA256withRSA**
        # *   **SHA256withRSA/PSS**
        # *   **SHA256withECDSA**
        # *   **SM3withSM2**
        # 
        # This parameter is required.
        self.signing_algorithm = signing_algorithm
        self.warehouse_id = warehouse_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.custom_identifier is not None:
            result['CustomIdentifier'] = self.custom_identifier

        if self.message is not None:
            result['Message'] = self.message

        if self.message_type is not None:
            result['MessageType'] = self.message_type

        if self.signature_value is not None:
            result['SignatureValue'] = self.signature_value

        if self.signing_algorithm is not None:
            result['SigningAlgorithm'] = self.signing_algorithm

        if self.warehouse_id is not None:
            result['WarehouseId'] = self.warehouse_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CustomIdentifier') is not None:
            self.custom_identifier = m.get('CustomIdentifier')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('MessageType') is not None:
            self.message_type = m.get('MessageType')

        if m.get('SignatureValue') is not None:
            self.signature_value = m.get('SignatureValue')

        if m.get('SigningAlgorithm') is not None:
            self.signing_algorithm = m.get('SigningAlgorithm')

        if m.get('WarehouseId') is not None:
            self.warehouse_id = m.get('WarehouseId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListCloudResourcesShrinkRequest(DaraModel):
    def __init__(
        self,
        cert_ids_shrink: str = None,
        cloud_name: str = None,
        cloud_product: str = None,
        current_page: int = None,
        keyword: str = None,
        secret_id: str = None,
        show_size: int = None,
    ):
        # The certificate IDs.
        self.cert_ids_shrink = cert_ids_shrink
        # The cloud service provider.
        # 
        # Valid values:
        # 
        # *   Tencent
        # *   Huawei
        # *   Aws
        # *   aliyun
        self.cloud_name = cloud_name
        # The cloud service.
        # 
        # Valid values when CloudName is set to aliyun:
        # 
        # *   SLB: Classic Load Balancer (CLB). This value is available only on the China site (aliyun.com).
        # *   LIVE: ApsaraVideo Live. This value is available only on the China site (aliyun.com).
        # *   webHosting: Cloud Web Hosting. This value is available only on the China site (aliyun.com).
        # *   VOD: ApsaraVideo VOD. This value is available only on the China site (aliyun.com).
        # *   CR: Container Registry. This value is available only on the China site (aliyun.com).
        # *   DCDN: Dynamic Content Delivery Network (DCDN).
        # *   DDOS: Anti-DDoS.
        # *   CDN: Alibaba Cloud CDN (CDN).
        # *   ALB: Application Load Balancer (ALB).
        # *   APIGateway: API Gateway.
        # *   FC: Function Compute.
        # *   GA: Global Accelerator (GA).
        # *   MSE: Microservices Engine (MSE).
        # *   NLB: Network Load Balancer (NLB).
        # *   OSS: Object Storage Service (OSS).
        # *   SAE: Serverless App Engine (SAE).
        # *   WAF: Web Application Firewall (WAF).
        # 
        # Valid values when CloudName is set to Tencent:
        # 
        # *   TencentCDN: Content Delivery Network (CDN).
        # *   TencentCLB: CLB.
        # *   TencentWAF: WAF.
        # 
        # Valid value when CloudName is set to Huawei:
        # 
        # *   HuaweiCDN: CDN.
        # 
        # Valid values when CloudName is set to Aws:
        # 
        # *   AwsCloudFront: Amazon CloudFront.
        # *   AwsCLB: CLB.
        # *   AwsALB: ALB.
        # *   AwsNLB: NLB.
        self.cloud_product = cloud_product
        # The page number. Default value: **1**.
        self.current_page = current_page
        # The keyword of the domain name or instance ID bound to the cloud resource.
        self.keyword = keyword
        # The AccessKey ID that is used to access cloud resources.
        self.secret_id = secret_id
        # The number of entries per page. Default value: **20**.
        self.show_size = show_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_ids_shrink is not None:
            result['CertIds'] = self.cert_ids_shrink

        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.cloud_product is not None:
            result['CloudProduct'] = self.cloud_product

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.keyword is not None:
            result['Keyword'] = self.keyword

        if self.secret_id is not None:
            result['SecretId'] = self.secret_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertIds') is not None:
            self.cert_ids_shrink = m.get('CertIds')

        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('CloudProduct') is not None:
            self.cloud_product = m.get('CloudProduct')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('Keyword') is not None:
            self.keyword = m.get('Keyword')

        if m.get('SecretId') is not None:
            self.secret_id = m.get('SecretId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class GetInstanceDetailResponseBody(DaraModel):
    def __init__(
        self,
        auto_reissue: str = None,
        average_waiting_time: str = None,
        brand: str = None,
        cert_identifier: str = None,
        certificate_id: int = None,
        certificate_name: str = None,
        certificate_not_after: int = None,
        certificate_revoke_time: int = None,
        certificate_status: str = None,
        certificate_type: str = None,
        city: str = None,
        company_id: int = None,
        contact_id_list: List[int] = None,
        country_code: str = None,
        csr: str = None,
        ding_group_list: List[main_models.GetInstanceDetailResponseBodyDingGroupList] = None,
        domain: str = None,
        domain_validation_list: List[main_models.GetInstanceDetailResponseBodyDomainValidationList] = None,
        full_domain_count: int = None,
        generate_csr_method: str = None,
        instance_end_time: int = None,
        instance_id: str = None,
        instance_start_time: int = None,
        instance_type: str = None,
        key_algorithm: str = None,
        order_end_time: int = None,
        order_start_time: int = None,
        pending_result: str = None,
        province: str = None,
        request_id: str = None,
        resource_group_id: str = None,
        spec: str = None,
        status: str = None,
        tags: List[main_models.GetInstanceDetailResponseBodyTags] = None,
        validation_method: str = None,
        wildcard_domain_count: int = None,
    ):
        self.auto_reissue = auto_reissue
        self.average_waiting_time = average_waiting_time
        self.brand = brand
        self.cert_identifier = cert_identifier
        self.certificate_id = certificate_id
        self.certificate_name = certificate_name
        self.certificate_not_after = certificate_not_after
        self.certificate_revoke_time = certificate_revoke_time
        self.certificate_status = certificate_status
        self.certificate_type = certificate_type
        self.city = city
        self.company_id = company_id
        self.contact_id_list = contact_id_list
        self.country_code = country_code
        self.csr = csr
        self.ding_group_list = ding_group_list
        self.domain = domain
        self.domain_validation_list = domain_validation_list
        self.full_domain_count = full_domain_count
        self.generate_csr_method = generate_csr_method
        self.instance_end_time = instance_end_time
        self.instance_id = instance_id
        self.instance_start_time = instance_start_time
        self.instance_type = instance_type
        self.key_algorithm = key_algorithm
        self.order_end_time = order_end_time
        self.order_start_time = order_start_time
        self.pending_result = pending_result
        self.province = province
        self.request_id = request_id
        self.resource_group_id = resource_group_id
        self.spec = spec
        self.status = status
        self.tags = tags
        self.validation_method = validation_method
        self.wildcard_domain_count = wildcard_domain_count

    def validate(self):
        if self.ding_group_list:
            for v1 in self.ding_group_list:
                 if v1:
                    v1.validate()
        if self.domain_validation_list:
            for v1 in self.domain_validation_list:
                 if v1:
                    v1.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_reissue is not None:
            result['AutoReissue'] = self.auto_reissue

        if self.average_waiting_time is not None:
            result['AverageWaitingTime'] = self.average_waiting_time

        if self.brand is not None:
            result['Brand'] = self.brand

        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.certificate_id is not None:
            result['CertificateId'] = self.certificate_id

        if self.certificate_name is not None:
            result['CertificateName'] = self.certificate_name

        if self.certificate_not_after is not None:
            result['CertificateNotAfter'] = self.certificate_not_after

        if self.certificate_revoke_time is not None:
            result['CertificateRevokeTime'] = self.certificate_revoke_time

        if self.certificate_status is not None:
            result['CertificateStatus'] = self.certificate_status

        if self.certificate_type is not None:
            result['CertificateType'] = self.certificate_type

        if self.city is not None:
            result['City'] = self.city

        if self.company_id is not None:
            result['CompanyId'] = self.company_id

        if self.contact_id_list is not None:
            result['ContactIdList'] = self.contact_id_list

        if self.country_code is not None:
            result['CountryCode'] = self.country_code

        if self.csr is not None:
            result['Csr'] = self.csr

        result['DingGroupList'] = []
        if self.ding_group_list is not None:
            for k1 in self.ding_group_list:
                result['DingGroupList'].append(k1.to_map() if k1 else None)

        if self.domain is not None:
            result['Domain'] = self.domain

        result['DomainValidationList'] = []
        if self.domain_validation_list is not None:
            for k1 in self.domain_validation_list:
                result['DomainValidationList'].append(k1.to_map() if k1 else None)

        if self.full_domain_count is not None:
            result['FullDomainCount'] = self.full_domain_count

        if self.generate_csr_method is not None:
            result['GenerateCsrMethod'] = self.generate_csr_method

        if self.instance_end_time is not None:
            result['InstanceEndTime'] = self.instance_end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.instance_start_time is not None:
            result['InstanceStartTime'] = self.instance_start_time

        if self.instance_type is not None:
            result['InstanceType'] = self.instance_type

        if self.key_algorithm is not None:
            result['KeyAlgorithm'] = self.key_algorithm

        if self.order_end_time is not None:
            result['OrderEndTime'] = self.order_end_time

        if self.order_start_time is not None:
            result['OrderStartTime'] = self.order_start_time

        if self.pending_result is not None:
            result['PendingResult'] = self.pending_result

        if self.province is not None:
            result['Province'] = self.province

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.spec is not None:
            result['Spec'] = self.spec

        if self.status is not None:
            result['Status'] = self.status

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.validation_method is not None:
            result['ValidationMethod'] = self.validation_method

        if self.wildcard_domain_count is not None:
            result['WildcardDomainCount'] = self.wildcard_domain_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoReissue') is not None:
            self.auto_reissue = m.get('AutoReissue')

        if m.get('AverageWaitingTime') is not None:
            self.average_waiting_time = m.get('AverageWaitingTime')

        if m.get('Brand') is not None:
            self.brand = m.get('Brand')

        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CertificateId') is not None:
            self.certificate_id = m.get('CertificateId')

        if m.get('CertificateName') is not None:
            self.certificate_name = m.get('CertificateName')

        if m.get('CertificateNotAfter') is not None:
            self.certificate_not_after = m.get('CertificateNotAfter')

        if m.get('CertificateRevokeTime') is not None:
            self.certificate_revoke_time = m.get('CertificateRevokeTime')

        if m.get('CertificateStatus') is not None:
            self.certificate_status = m.get('CertificateStatus')

        if m.get('CertificateType') is not None:
            self.certificate_type = m.get('CertificateType')

        if m.get('City') is not None:
            self.city = m.get('City')

        if m.get('CompanyId') is not None:
            self.company_id = m.get('CompanyId')

        if m.get('ContactIdList') is not None:
            self.contact_id_list = m.get('ContactIdList')

        if m.get('CountryCode') is not None:
            self.country_code = m.get('CountryCode')

        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        self.ding_group_list = []
        if m.get('DingGroupList') is not None:
            for k1 in m.get('DingGroupList'):
                temp_model = main_models.GetInstanceDetailResponseBodyDingGroupList()
                self.ding_group_list.append(temp_model.from_map(k1))

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        self.domain_validation_list = []
        if m.get('DomainValidationList') is not None:
            for k1 in m.get('DomainValidationList'):
                temp_model = main_models.GetInstanceDetailResponseBodyDomainValidationList()
                self.domain_validation_list.append(temp_model.from_map(k1))

        if m.get('FullDomainCount') is not None:
            self.full_domain_count = m.get('FullDomainCount')

        if m.get('GenerateCsrMethod') is not None:
            self.generate_csr_method = m.get('GenerateCsrMethod')

        if m.get('InstanceEndTime') is not None:
            self.instance_end_time = m.get('InstanceEndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('InstanceStartTime') is not None:
            self.instance_start_time = m.get('InstanceStartTime')

        if m.get('InstanceType') is not None:
            self.instance_type = m.get('InstanceType')

        if m.get('KeyAlgorithm') is not None:
            self.key_algorithm = m.get('KeyAlgorithm')

        if m.get('OrderEndTime') is not None:
            self.order_end_time = m.get('OrderEndTime')

        if m.get('OrderStartTime') is not None:
            self.order_start_time = m.get('OrderStartTime')

        if m.get('PendingResult') is not None:
            self.pending_result = m.get('PendingResult')

        if m.get('Province') is not None:
            self.province = m.get('Province')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('Spec') is not None:
            self.spec = m.get('Spec')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.GetInstanceDetailResponseBodyTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('ValidationMethod') is not None:
            self.validation_method = m.get('ValidationMethod')

        if m.get('WildcardDomainCount') is not None:
            self.wildcard_domain_count = m.get('WildcardDomainCount')

        return self

class GetInstanceDetailResponseBodyTags(DaraModel):
    def __init__(
        self,
        tag_key: str = None,
        tag_value: str = None,
    ):
        self.tag_key = tag_key
        self.tag_value = tag_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.tag_key is not None:
            result['TagKey'] = self.tag_key

        if self.tag_value is not None:
            result['TagValue'] = self.tag_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('TagKey') is not None:
            self.tag_key = m.get('TagKey')

        if m.get('TagValue') is not None:
            self.tag_value = m.get('TagValue')

        return self

class GetInstanceDetailResponseBodyDomainValidationList(DaraModel):
    def __init__(
        self,
        cname: str = None,
        domain: str = None,
        root_domain: str = None,
        validation_key: str = None,
        validation_type: str = None,
        validation_value: str = None,
    ):
        self.cname = cname
        self.domain = domain
        self.root_domain = root_domain
        self.validation_key = validation_key
        self.validation_type = validation_type
        self.validation_value = validation_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cname is not None:
            result['Cname'] = self.cname

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.root_domain is not None:
            result['RootDomain'] = self.root_domain

        if self.validation_key is not None:
            result['ValidationKey'] = self.validation_key

        if self.validation_type is not None:
            result['ValidationType'] = self.validation_type

        if self.validation_value is not None:
            result['ValidationValue'] = self.validation_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Cname') is not None:
            self.cname = m.get('Cname')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('RootDomain') is not None:
            self.root_domain = m.get('RootDomain')

        if m.get('ValidationKey') is not None:
            self.validation_key = m.get('ValidationKey')

        if m.get('ValidationType') is not None:
            self.validation_type = m.get('ValidationType')

        if m.get('ValidationValue') is not None:
            self.validation_value = m.get('ValidationValue')

        return self

class GetInstanceDetailResponseBodyDingGroupList(DaraModel):
    def __init__(
        self,
        ding_group_instance_id: str = None,
        ding_group_name: str = None,
        ding_group_type: str = None,
        ding_group_url: str = None,
    ):
        self.ding_group_instance_id = ding_group_instance_id
        self.ding_group_name = ding_group_name
        self.ding_group_type = ding_group_type
        self.ding_group_url = ding_group_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ding_group_instance_id is not None:
            result['DingGroupInstanceId'] = self.ding_group_instance_id

        if self.ding_group_name is not None:
            result['DingGroupName'] = self.ding_group_name

        if self.ding_group_type is not None:
            result['DingGroupType'] = self.ding_group_type

        if self.ding_group_url is not None:
            result['DingGroupUrl'] = self.ding_group_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DingGroupInstanceId') is not None:
            self.ding_group_instance_id = m.get('DingGroupInstanceId')

        if m.get('DingGroupName') is not None:
            self.ding_group_name = m.get('DingGroupName')

        if m.get('DingGroupType') is not None:
            self.ding_group_type = m.get('DingGroupType')

        if m.get('DingGroupUrl') is not None:
            self.ding_group_url = m.get('DingGroupUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListInstancesResponseBody(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        instance_list: List[main_models.ListInstancesResponseBodyInstanceList] = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        self.current_page = current_page
        self.instance_list = instance_list
        self.request_id = request_id
        self.show_size = show_size
        self.total_count = total_count

    def validate(self):
        if self.instance_list:
            for v1 in self.instance_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        result['InstanceList'] = []
        if self.instance_list is not None:
            for k1 in self.instance_list:
                result['InstanceList'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        self.instance_list = []
        if m.get('InstanceList') is not None:
            for k1 in m.get('InstanceList'):
                temp_model = main_models.ListInstancesResponseBodyInstanceList()
                self.instance_list.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListInstancesResponseBodyInstanceList(DaraModel):
    def __init__(
        self,
        auto_reissue: str = None,
        brand: str = None,
        cert_identifier: str = None,
        certificate_id: int = None,
        certificate_name: str = None,
        certificate_not_after: int = None,
        certificate_revoke_time: int = None,
        certificate_status: str = None,
        certificate_type: str = None,
        domain: str = None,
        full_domain_count: int = None,
        instance_end_time: int = None,
        instance_id: str = None,
        instance_start_time: int = None,
        instance_type: str = None,
        key_algorithm: str = None,
        order_end_time: int = None,
        order_start_time: int = None,
        pending_result: str = None,
        spec: str = None,
        status: str = None,
        wildcard_domain_count: int = None,
    ):
        self.auto_reissue = auto_reissue
        self.brand = brand
        self.cert_identifier = cert_identifier
        self.certificate_id = certificate_id
        self.certificate_name = certificate_name
        self.certificate_not_after = certificate_not_after
        self.certificate_revoke_time = certificate_revoke_time
        self.certificate_status = certificate_status
        self.certificate_type = certificate_type
        self.domain = domain
        self.full_domain_count = full_domain_count
        self.instance_end_time = instance_end_time
        self.instance_id = instance_id
        self.instance_start_time = instance_start_time
        self.instance_type = instance_type
        self.key_algorithm = key_algorithm
        self.order_end_time = order_end_time
        self.order_start_time = order_start_time
        self.pending_result = pending_result
        self.spec = spec
        self.status = status
        self.wildcard_domain_count = wildcard_domain_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_reissue is not None:
            result['AutoReissue'] = self.auto_reissue

        if self.brand is not None:
            result['Brand'] = self.brand

        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.certificate_id is not None:
            result['CertificateId'] = self.certificate_id

        if self.certificate_name is not None:
            result['CertificateName'] = self.certificate_name

        if self.certificate_not_after is not None:
            result['CertificateNotAfter'] = self.certificate_not_after

        if self.certificate_revoke_time is not None:
            result['CertificateRevokeTime'] = self.certificate_revoke_time

        if self.certificate_status is not None:
            result['CertificateStatus'] = self.certificate_status

        if self.certificate_type is not None:
            result['CertificateType'] = self.certificate_type

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.full_domain_count is not None:
            result['FullDomainCount'] = self.full_domain_count

        if self.instance_end_time is not None:
            result['InstanceEndTime'] = self.instance_end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.instance_start_time is not None:
            result['InstanceStartTime'] = self.instance_start_time

        if self.instance_type is not None:
            result['InstanceType'] = self.instance_type

        if self.key_algorithm is not None:
            result['KeyAlgorithm'] = self.key_algorithm

        if self.order_end_time is not None:
            result['OrderEndTime'] = self.order_end_time

        if self.order_start_time is not None:
            result['OrderStartTime'] = self.order_start_time

        if self.pending_result is not None:
            result['PendingResult'] = self.pending_result

        if self.spec is not None:
            result['Spec'] = self.spec

        if self.status is not None:
            result['Status'] = self.status

        if self.wildcard_domain_count is not None:
            result['WildcardDomainCount'] = self.wildcard_domain_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoReissue') is not None:
            self.auto_reissue = m.get('AutoReissue')

        if m.get('Brand') is not None:
            self.brand = m.get('Brand')

        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CertificateId') is not None:
            self.certificate_id = m.get('CertificateId')

        if m.get('CertificateName') is not None:
            self.certificate_name = m.get('CertificateName')

        if m.get('CertificateNotAfter') is not None:
            self.certificate_not_after = m.get('CertificateNotAfter')

        if m.get('CertificateRevokeTime') is not None:
            self.certificate_revoke_time = m.get('CertificateRevokeTime')

        if m.get('CertificateStatus') is not None:
            self.certificate_status = m.get('CertificateStatus')

        if m.get('CertificateType') is not None:
            self.certificate_type = m.get('CertificateType')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('FullDomainCount') is not None:
            self.full_domain_count = m.get('FullDomainCount')

        if m.get('InstanceEndTime') is not None:
            self.instance_end_time = m.get('InstanceEndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('InstanceStartTime') is not None:
            self.instance_start_time = m.get('InstanceStartTime')

        if m.get('InstanceType') is not None:
            self.instance_type = m.get('InstanceType')

        if m.get('KeyAlgorithm') is not None:
            self.key_algorithm = m.get('KeyAlgorithm')

        if m.get('OrderEndTime') is not None:
            self.order_end_time = m.get('OrderEndTime')

        if m.get('OrderStartTime') is not None:
            self.order_start_time = m.get('OrderStartTime')

        if m.get('PendingResult') is not None:
            self.pending_result = m.get('PendingResult')

        if m.get('Spec') is not None:
            self.spec = m.get('Spec')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('WildcardDomainCount') is not None:
            self.wildcard_domain_count = m.get('WildcardDomainCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetCsrDetailResponseBody(DaraModel):
    def __init__(
        self,
        csr: str = None,
        private_key: str = None,
        request_id: str = None,
    ):
        # The content of the CSR.
        self.csr = csr
        # The private key. Specify a Base64-encoded string.
        self.private_key = private_key
        # The request ID.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.csr is not None:
            result['Csr'] = self.csr

        if self.private_key is not None:
            result['PrivateKey'] = self.private_key

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('PrivateKey') is not None:
            self.private_key = m.get('PrivateKey')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class MoveResourceGroupRequest(DaraModel):
    def __init__(
        self,
        region_id: str = None,
        resource_group_id: str = None,
        resource_id: str = None,
        resource_type: str = None,
    ):
        # The region of the organization to which the owner of the certificate belongs. Valid values: ap-southeast-1 and cn-hangzhou.
        self.region_id = region_id
        # The ID of the resource group.
        # 
        # This parameter is required.
        self.resource_group_id = resource_group_id
        # The ID of the resource.
        # 
        # This parameter is required.
        self.resource_id = resource_id
        # The type of the resource.\\
        # Default value: **instance**
        # 
        # Valid values:
        # 
        # *   instance: certificate order
        # *   Certificate: certificate
        # 
        # This parameter is required.
        self.resource_type = resource_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.resource_id is not None:
            result['ResourceId'] = self.resource_id

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('ResourceId') is not None:
            self.resource_id = m.get('ResourceId')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateWarehouseResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        warehouse_instance_id: str = None,
    ):
        self.request_id = request_id
        self.warehouse_instance_id = warehouse_instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.warehouse_instance_id is not None:
            result['WarehouseInstanceId'] = self.warehouse_instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('WarehouseInstanceId') is not None:
            self.warehouse_instance_id = m.get('WarehouseInstanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListCloudResourcesResponseBody(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        data: List[main_models.ListCloudResourcesResponseBodyData] = None,
        request_id: str = None,
        show_size: int = None,
        total: int = None,
    ):
        # The page number. Default value: 1.
        self.current_page = current_page
        # The data returned for the request.
        self.data = data
        # The request ID.
        self.request_id = request_id
        # The number of entries per page. Default value: **20**.
        self.show_size = show_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListCloudResourcesResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class ListCloudResourcesResponseBodyData(DaraModel):
    def __init__(
        self,
        cert_end_time: str = None,
        cert_id: int = None,
        cert_name: str = None,
        cert_start_time: str = None,
        cloud_access_id: str = None,
        cloud_name: str = None,
        cloud_product: str = None,
        cloud_region: str = None,
        default_resource: int = None,
        domain: str = None,
        enable_https: int = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        instance_id: str = None,
        listener_id: str = None,
        listener_port: str = None,
        region_id: str = None,
        status: str = None,
        use_ssl: int = None,
        user_id: int = None,
    ):
        # The end date of the certificate bound to the cloud resource. The value is a timestamp in seconds.
        self.cert_end_time = cert_end_time
        # The ID of the certificate bound to the cloud resource.
        self.cert_id = cert_id
        # The name of the certificate bound to the cloud resource.
        self.cert_name = cert_name
        # The start date of the certificate bound to the cloud resource. The value is a timestamp in seconds.
        self.cert_start_time = cert_start_time
        # The AccessKey ID that is used to access cloud resources.
        # 
        # >  This parameter is returned only when you deploy certificates to cloud services of third-party clouds.
        self.cloud_access_id = cloud_access_id
        # The cloud service provider.
        # 
        # Valid values:
        # 
        # *   Tencent
        # *   Huawei
        # *   Aws
        # *   aliyun
        self.cloud_name = cloud_name
        # The cloud service.
        self.cloud_product = cloud_product
        # The region ID of the cloud service provider to which the cloud resource belongs.
        self.cloud_region = cloud_region
        # Indicates whether the cloud resource is the default resource. Valid values:
        # 
        # *   **1**: yes
        # *   **0**: no
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.default_resource = default_resource
        # The domain name bound to the cloud resource.
        self.domain = domain
        # Indicates whether HTTPS is enabled for the cloud resource. Valid values:
        # 
        # *   **1**: yes.
        # *   **0**: no.
        self.enable_https = enable_https
        # The time when the cloud resource was created. The time is a timestamp in seconds.
        self.gmt_create = gmt_create
        # The time when the cloud resource was last modified. The time is a timestamp in seconds.
        self.gmt_modified = gmt_modified
        # The ID of the cloud resource.
        self.id = id
        # The instance ID of the cloud resource.
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.instance_id = instance_id
        # The listener ID of the cloud resource.
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.listener_id = listener_id
        # The listening port of the cloud resource.
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.listener_port = listener_port
        # The region ID of the cloud resource.
        self.region_id = region_id
        # The status of the cloud resource.
        self.status = status
        # Indicates whether an Alibaba Cloud SSL certificate is used. Valid values:
        # 
        # *   **1**: yes
        # *   **0**: no
        # 
        # >  This parameter is required only when you deploy certificates to services of multiple clouds.
        self.use_ssl = use_ssl
        # The ID of the Alibaba Cloud account.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_end_time is not None:
            result['CertEndTime'] = self.cert_end_time

        if self.cert_id is not None:
            result['CertId'] = self.cert_id

        if self.cert_name is not None:
            result['CertName'] = self.cert_name

        if self.cert_start_time is not None:
            result['CertStartTime'] = self.cert_start_time

        if self.cloud_access_id is not None:
            result['CloudAccessId'] = self.cloud_access_id

        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.cloud_product is not None:
            result['CloudProduct'] = self.cloud_product

        if self.cloud_region is not None:
            result['CloudRegion'] = self.cloud_region

        if self.default_resource is not None:
            result['DefaultResource'] = self.default_resource

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.enable_https is not None:
            result['EnableHttps'] = self.enable_https

        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['GmtModified'] = self.gmt_modified

        if self.id is not None:
            result['Id'] = self.id

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.listener_id is not None:
            result['ListenerId'] = self.listener_id

        if self.listener_port is not None:
            result['ListenerPort'] = self.listener_port

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.status is not None:
            result['Status'] = self.status

        if self.use_ssl is not None:
            result['UseSsl'] = self.use_ssl

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertEndTime') is not None:
            self.cert_end_time = m.get('CertEndTime')

        if m.get('CertId') is not None:
            self.cert_id = m.get('CertId')

        if m.get('CertName') is not None:
            self.cert_name = m.get('CertName')

        if m.get('CertStartTime') is not None:
            self.cert_start_time = m.get('CertStartTime')

        if m.get('CloudAccessId') is not None:
            self.cloud_access_id = m.get('CloudAccessId')

        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('CloudProduct') is not None:
            self.cloud_product = m.get('CloudProduct')

        if m.get('CloudRegion') is not None:
            self.cloud_region = m.get('CloudRegion')

        if m.get('DefaultResource') is not None:
            self.default_resource = m.get('DefaultResource')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('EnableHttps') is not None:
            self.enable_https = m.get('EnableHttps')

        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')

        if m.get('GmtModified') is not None:
            self.gmt_modified = m.get('GmtModified')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('ListenerId') is not None:
            self.listener_id = m.get('ListenerId')

        if m.get('ListenerPort') is not None:
            self.listener_port = m.get('ListenerPort')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('UseSsl') is not None:
            self.use_ssl = m.get('UseSsl')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UploadPCACertRequest(DaraModel):
    def __init__(
        self,
        cert: str = None,
        name: str = None,
        private_key: str = None,
        warehouse_id: int = None,
    ):
        # <UploadPCACertResponse>
        #     <RequestId>15C66C7B-671A-4297-9187-2C4477247A74</RequestId>
        # </UploadPCACertResponse>
        # 
        # This parameter is required.
        self.cert = cert
        # UploadPCACert
        self.name = name
        # Uploads a private certificate to a certificate repository.
        self.private_key = private_key
        # The ID of the repository.
        # 
        # >  You can call the [ListCertWarehouse](https://help.aliyun.com/document_detail/455805.html) operation to query the ID.
        # 
        # This parameter is required.
        self.warehouse_id = warehouse_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert is not None:
            result['Cert'] = self.cert

        if self.name is not None:
            result['Name'] = self.name

        if self.private_key is not None:
            result['PrivateKey'] = self.private_key

        if self.warehouse_id is not None:
            result['WarehouseId'] = self.warehouse_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Cert') is not None:
            self.cert = m.get('Cert')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('PrivateKey') is not None:
            self.private_key = m.get('PrivateKey')

        if m.get('WarehouseId') is not None:
            self.warehouse_id = m.get('WarehouseId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAssetCountResponseBody(DaraModel):
    def __init__(
        self,
        aliyun_asset_count: int = None,
        aws_asset_count: int = None,
        buy_certificate_count: int = None,
        domain_asset_count: int = None,
        free_certificate_count: int = None,
        huawei_asset_count: int = None,
        last_point: int = None,
        point: int = None,
        point_ratio: int = None,
        point_time: int = None,
        request_id: str = None,
        tencent_asset_count: int = None,
        upload_certificate_count: int = None,
    ):
        self.aliyun_asset_count = aliyun_asset_count
        self.aws_asset_count = aws_asset_count
        self.buy_certificate_count = buy_certificate_count
        self.domain_asset_count = domain_asset_count
        self.free_certificate_count = free_certificate_count
        self.huawei_asset_count = huawei_asset_count
        self.last_point = last_point
        self.point = point
        self.point_ratio = point_ratio
        self.point_time = point_time
        self.request_id = request_id
        self.tencent_asset_count = tencent_asset_count
        self.upload_certificate_count = upload_certificate_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_asset_count is not None:
            result['AliyunAssetCount'] = self.aliyun_asset_count

        if self.aws_asset_count is not None:
            result['AwsAssetCount'] = self.aws_asset_count

        if self.buy_certificate_count is not None:
            result['BuyCertificateCount'] = self.buy_certificate_count

        if self.domain_asset_count is not None:
            result['DomainAssetCount'] = self.domain_asset_count

        if self.free_certificate_count is not None:
            result['FreeCertificateCount'] = self.free_certificate_count

        if self.huawei_asset_count is not None:
            result['HuaweiAssetCount'] = self.huawei_asset_count

        if self.last_point is not None:
            result['LastPoint'] = self.last_point

        if self.point is not None:
            result['Point'] = self.point

        if self.point_ratio is not None:
            result['PointRatio'] = self.point_ratio

        if self.point_time is not None:
            result['PointTime'] = self.point_time

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.tencent_asset_count is not None:
            result['TencentAssetCount'] = self.tencent_asset_count

        if self.upload_certificate_count is not None:
            result['UploadCertificateCount'] = self.upload_certificate_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AliyunAssetCount') is not None:
            self.aliyun_asset_count = m.get('AliyunAssetCount')

        if m.get('AwsAssetCount') is not None:
            self.aws_asset_count = m.get('AwsAssetCount')

        if m.get('BuyCertificateCount') is not None:
            self.buy_certificate_count = m.get('BuyCertificateCount')

        if m.get('DomainAssetCount') is not None:
            self.domain_asset_count = m.get('DomainAssetCount')

        if m.get('FreeCertificateCount') is not None:
            self.free_certificate_count = m.get('FreeCertificateCount')

        if m.get('HuaweiAssetCount') is not None:
            self.huawei_asset_count = m.get('HuaweiAssetCount')

        if m.get('LastPoint') is not None:
            self.last_point = m.get('LastPoint')

        if m.get('Point') is not None:
            self.point = m.get('Point')

        if m.get('PointRatio') is not None:
            self.point_ratio = m.get('PointRatio')

        if m.get('PointTime') is not None:
            self.point_time = m.get('PointTime')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TencentAssetCount') is not None:
            self.tencent_asset_count = m.get('TencentAssetCount')

        if m.get('UploadCertificateCount') is not None:
            self.upload_certificate_count = m.get('UploadCertificateCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListWarehouseRequest(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        next_token: str = None,
        warehouse_instance_ids: List[str] = None,
        warehouse_types: List[str] = None,
    ):
        self.max_results = max_results
        self.next_token = next_token
        self.warehouse_instance_ids = warehouse_instance_ids
        self.warehouse_types = warehouse_types

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['MaxResults'] = self.max_results

        if self.next_token is not None:
            result['NextToken'] = self.next_token

        if self.warehouse_instance_ids is not None:
            result['WarehouseInstanceIds'] = self.warehouse_instance_ids

        if self.warehouse_types is not None:
            result['WarehouseTypes'] = self.warehouse_types

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('MaxResults') is not None:
            self.max_results = m.get('MaxResults')

        if m.get('NextToken') is not None:
            self.next_token = m.get('NextToken')

        if m.get('WarehouseInstanceIds') is not None:
            self.warehouse_instance_ids = m.get('WarehouseInstanceIds')

        if m.get('WarehouseTypes') is not None:
            self.warehouse_types = m.get('WarehouseTypes')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribePackageStateResponseBody(DaraModel):
    def __init__(
        self,
        issued_count: int = None,
        product_code: str = None,
        request_id: str = None,
        total_count: int = None,
        used_count: int = None,
    ):
        # The number of issued certificates of the specified specifications.
        self.issued_count = issued_count
        # The specifications of the certificate resource plan. Valid values:
        # 
        # *   **digicert-free-1-free**: DigiCert single-domain DV certificate in a three-month free trial, available only on the China site (aliyun.com).
        # *   **symantec-free-1-free**: DigiCert single-domain DV certificate in a one-year free trial, available only on the China site (aliyun.com).
        # *   **symantec-dv-1-starter**: DigiCert wildcard DV certificate.
        # *   **symantec-ov-1-personal**: DigiCert single-domain OV certificate.
        # *   **symantec-ov-w-personal**: DigiCert wildcard OV certificate.
        # *   **geotrust-dv-1-starter**: GeoTrust single-domain DV certificate.
        # *   **geotrust-dv-w-starter**: GeoTrust wildcard DV certificate.
        # *   **geotrust-ov-1-personal**: GeoTrust single-domain OV certificate.
        # *   **geotrust-ov-w-personal**: GeoTrust wildcard OV certificate.
        # *   **globalsign-dv-1-personal**: GlobalSign single-domain DV certificate.
        # *   **globalsign-dv-w-advanced**: GlobalSign wildcard DV certificate.
        # *   **globalsign-ov-1-personal**: GlobalSign single-domain OV certificate.
        # *   **globalsign-ov-w-advanced**: GlobalSign wildcard OV certificate.
        # *   **cfca-ov-1-personal**: CFCA single-domain OV certificate, available only on the China site (aliyun.com).
        # *   **cfca-ev-w-advanced**: CFCA wildcard OV certificate, available only on the China site (aliyun.com).
        self.product_code = product_code
        # The ID of the request, which is used to locate and troubleshoot issues.
        self.request_id = request_id
        # The total number of purchased certificate resource plans of the specified specifications.
        self.total_count = total_count
        # The number of certificate applications that you submitted for certificates of the specified specifications.
        # 
        # > : A successful call of the [CreateCertificateForPackageRequest](https://help.aliyun.com/document_detail/204087.html), [CreateCertificateRequest](https://help.aliyun.com/document_detail/164105.html), or [CreateCertificateWithCsrRequest](https://help.aliyun.com/document_detail/178732.html) operation is counted as one a certificate application, regardless of whether the certificate is issued.
        self.used_count = used_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.issued_count is not None:
            result['IssuedCount'] = self.issued_count

        if self.product_code is not None:
            result['ProductCode'] = self.product_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        if self.used_count is not None:
            result['UsedCount'] = self.used_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('IssuedCount') is not None:
            self.issued_count = m.get('IssuedCount')

        if m.get('ProductCode') is not None:
            self.product_code = m.get('ProductCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        if m.get('UsedCount') is not None:
            self.used_count = m.get('UsedCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListCertRequest(DaraModel):
    def __init__(
        self,
        cert_type: str = None,
        current_page: int = None,
        identifiers: str = None,
        key_word: str = None,
        show_size: int = None,
        source_type: str = None,
        status: str = None,
        warehouse_id: int = None,
    ):
        # 证书的类型 。取值：
        # 
        # - **CA**：表示CA证书。
        # - **CERT**：表示签发的证书。
        self.cert_type = cert_type
        # The number of the page to return. Default value: 1.
        self.current_page = current_page
        self.identifiers = identifiers
        # The keyword for the query. You can enter a name, domain name, or Subject Alternative Name (SAN) extension. Fuzzy match is supported.
        self.key_word = key_word
        # The number of entries to return on each page. Default value: 50.
        self.show_size = show_size
        # The source of the certificate. Valid values:
        # 
        # *   **upload**: uploaded certificate
        # *   **aliyun**: Alibaba Cloud certificate
        self.source_type = source_type
        # The status of the certificate. Valid values:
        # 
        # *   **ISSUE**: issued
        # *   **REVOKE**: revoked
        self.status = status
        # The ID of the certificate repository. You can call the ListCertWarehouse API operation to query the IDs of certificate repositories.
        self.warehouse_id = warehouse_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_type is not None:
            result['CertType'] = self.cert_type

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.identifiers is not None:
            result['Identifiers'] = self.identifiers

        if self.key_word is not None:
            result['KeyWord'] = self.key_word

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.source_type is not None:
            result['SourceType'] = self.source_type

        if self.status is not None:
            result['Status'] = self.status

        if self.warehouse_id is not None:
            result['WarehouseId'] = self.warehouse_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertType') is not None:
            self.cert_type = m.get('CertType')

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('Identifiers') is not None:
            self.identifiers = m.get('Identifiers')

        if m.get('KeyWord') is not None:
            self.key_word = m.get('KeyWord')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('SourceType') is not None:
            self.source_type = m.get('SourceType')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('WarehouseId') is not None:
            self.warehouse_id = m.get('WarehouseId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetInstanceSummaryResponseBody(DaraModel):
    def __init__(
        self,
        auto_reissue_count: int = None,
        certificate_count: int = None,
        inactive_count: int = None,
        request_id: str = None,
        total_count: int = None,
        will_expire_count: int = None,
    ):
        self.auto_reissue_count = auto_reissue_count
        self.certificate_count = certificate_count
        self.inactive_count = inactive_count
        self.request_id = request_id
        self.total_count = total_count
        self.will_expire_count = will_expire_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_reissue_count is not None:
            result['AutoReissueCount'] = self.auto_reissue_count

        if self.certificate_count is not None:
            result['CertificateCount'] = self.certificate_count

        if self.inactive_count is not None:
            result['InactiveCount'] = self.inactive_count

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        if self.will_expire_count is not None:
            result['WillExpireCount'] = self.will_expire_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoReissueCount') is not None:
            self.auto_reissue_count = m.get('AutoReissueCount')

        if m.get('CertificateCount') is not None:
            self.certificate_count = m.get('CertificateCount')

        if m.get('InactiveCount') is not None:
            self.inactive_count = m.get('InactiveCount')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        if m.get('WillExpireCount') is not None:
            self.will_expire_count = m.get('WillExpireCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class CreateCertificateRequestRequest(DaraModel):
    def __init__(
        self,
        domain: str = None,
        email: str = None,
        phone: str = None,
        product_code: str = None,
        tags: List[main_models.CreateCertificateRequestRequestTags] = None,
        username: str = None,
        validate_type: str = None,
    ):
        # The domain name that you want to bind to the certificate. You can specify only one domain name.
        # 
        # >  The domain name must match the certificate specifications that you specify for the **ProductCode** parameter. If you apply for a single-domain certificate, you must specify a single domain name for this parameter. If you apply for a wildcard certificate, you must specify a wildcard domain name such as `*.aliyundoc.com` for this parameter.
        # 
        # This parameter is required.
        self.domain = domain
        # The contact email address of the applicant.
        # 
        # This parameter is required.
        self.email = email
        # The phone number of the applicant.
        # 
        # This parameter is required.
        self.phone = phone
        # The specifications of the certificate. Valid values:
        # 
        # *   **digicert-free-1-free** (default): DigiCert single-domain DV certificate, which is free and valid for 3 months.
        # *   **symantec-free-1-free**: DigiCert single-domain DV certificate, which is free and valid for 1 year. This value is available only on the China site (aliyun.com).
        # *   **symantec-dv-1-starter**: DigiCert wildcard DV certificate.
        # *   **geotrust-dv-1-starter**: GeoTrust single-domain DV certificate.
        # *   **geotrust-dv-w-starter**: GeoTrust wildcard DV certificate.
        # *   **globalsign-dv-1-personal**: GlobalSign single-domain DV certificate.
        # *   **globalsign-dv-w-advanced**: GlobalSign wildcard DV certificate.
        self.product_code = product_code
        # The tags.
        self.tags = tags
        # The name of the applicant.
        # 
        # This parameter is required.
        self.username = username
        # The method to verify the ownership of a domain name. Valid values:
        # 
        # *   **DNS**: DNS verification. If you use this method, you must add a TXT record to the DNS records of the domain name in the management platform of the domain name. You must have operation permissions on domain name resolution to verify the ownership of the domain name.
        # *   **FILE**: file verification. If you use this method, you must create a specified file on the DNS server. You must have administrative rights on the DNS server to verify the ownership of the domain name.
        # 
        # For more information about the verification methods, see [Verify the ownership of a domain name](https://help.aliyun.com/document_detail/48016.html).
        # 
        # This parameter is required.
        self.validate_type = validate_type

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.domain is not None:
            result['Domain'] = self.domain

        if self.email is not None:
            result['Email'] = self.email

        if self.phone is not None:
            result['Phone'] = self.phone

        if self.product_code is not None:
            result['ProductCode'] = self.product_code

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.username is not None:
            result['Username'] = self.username

        if self.validate_type is not None:
            result['ValidateType'] = self.validate_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('Email') is not None:
            self.email = m.get('Email')

        if m.get('Phone') is not None:
            self.phone = m.get('Phone')

        if m.get('ProductCode') is not None:
            self.product_code = m.get('ProductCode')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.CreateCertificateRequestRequestTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('Username') is not None:
            self.username = m.get('Username')

        if m.get('ValidateType') is not None:
            self.validate_type = m.get('ValidateType')

        return self

class CreateCertificateRequestRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key of the resource. You can specify up to 20 tag keys. You cannot specify empty strings as tag keys.
        # 
        # The key can be up to 64 characters in length and can contain letters, digits, periods (.), underscores (_), and hyphens (-). The key must start with a letter but cannot start with `aliyun` or `acs:`. The key cannot contain `http://` or `https://`.
        # 
        # >  You must specify at least one of **Tag.N** (**Tag.N.Key** and **Tag.N.Value**).
        self.key = key
        # The tag value. You can specify up to 20 tag values. The tag value can be an empty string.
        # 
        # The tag value cannot exceed 128 characters in length, and can contain digits, periods (.), underscores (_), and hyphens (-). The key must start with a letter but cannot start with `aliyun` or `acs:`. The key cannot contain `http://` or `https://`.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class CreateCertificateWithCsrRequestRequest(DaraModel):
    def __init__(
        self,
        csr: str = None,
        email: str = None,
        phone: str = None,
        product_code: str = None,
        tags: List[main_models.CreateCertificateWithCsrRequestRequestTags] = None,
        username: str = None,
        validate_type: str = None,
    ):
        # The content of the CSR file.\\
        # The key algorithm in the CSR file must be Rivest-Shamir-Adleman (RSA) or elliptic-curve cryptography (ECC), and the key length of the RSA algorithm must be greater than or equal to 2,048 characters. For more information about how to create a CSR file, see [How do I create a CSR file?](https://help.aliyun.com/document_detail/42218.html)\\
        # A CSR file contains the information about your server and company. When you apply for a certificate, you must submit the CSR file to the CA. The CA signs the CSR file by using the private key of the root certificate and generates a public key file to issue your certificate.
        # 
        # >  The **CN** field in the CSR file specifies the domain name that is bound to the certificate.
        # 
        # This parameter is required.
        self.csr = csr
        # The contact email address of the applicant.
        # 
        # This parameter is required.
        self.email = email
        # The phone number of the applicant.
        # 
        # This parameter is required.
        self.phone = phone
        # The specifications of the certificate that you want to apply for. Valid values:
        # 
        # *   **digicert-free-1-free** (default): DigiCert single-domain DV certificate in a three-month free trial, available only on the China site (aliyun.com).
        # *   **symantec-free-1-free**: DigiCert single-domain DV certificate in a one-year free trial, available only on the China site (aliyun.com).
        # *   **symantec-dv-1-starter**: DigiCert wildcard DV certificate.
        # *   **geotrust-dv-1-starter**: GeoTrust single-domain DV certificate.
        # *   **geotrust-dv-w-starter**: GeoTrust wildcard DV certificate.
        # *   **globalsign-dv-1-personal**: GlobalSign single-domain DV certificate.
        # *   **globalsign-dv-w-advanced**: GlobalSign wildcard DV certificate.
        self.product_code = product_code
        # The tag list.
        self.tags = tags
        # The name of the applicant.
        # 
        # This parameter is required.
        self.username = username
        # The method to verify the ownership of a domain name. Valid values:
        # 
        # *   **DNS**: DNS verification. If you use this method, you must add a TXT record to the DNS records of the domain name in the management platform of the domain name. You must have operation permissions on domain name resolution to verify the ownership of the domain name.
        # *   **FILE**: file verification. If you use this method, you must create a specified file on the DNS server. You must have administrative rights on the DNS server to verify the ownership of the domain name.
        # 
        # For more information about the verification methods, see [Verify the ownership of a domain name](https://help.aliyun.com/document_detail/48016.html).
        # 
        # This parameter is required.
        self.validate_type = validate_type

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.csr is not None:
            result['Csr'] = self.csr

        if self.email is not None:
            result['Email'] = self.email

        if self.phone is not None:
            result['Phone'] = self.phone

        if self.product_code is not None:
            result['ProductCode'] = self.product_code

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.username is not None:
            result['Username'] = self.username

        if self.validate_type is not None:
            result['ValidateType'] = self.validate_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('Email') is not None:
            self.email = m.get('Email')

        if m.get('Phone') is not None:
            self.phone = m.get('Phone')

        if m.get('ProductCode') is not None:
            self.product_code = m.get('ProductCode')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.CreateCertificateWithCsrRequestRequestTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('Username') is not None:
            self.username = m.get('Username')

        if m.get('ValidateType') is not None:
            self.validate_type = m.get('ValidateType')

        return self

class CreateCertificateWithCsrRequestRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key. Valid values of N: 1 to 20. The tag key cannot be an empty string. The tag key can be up to 128 characters in length and cannot start with `acs:` or `aliyun`. The tag key cannot contain `http://` or `https://`.
        self.key = key
        # The value of the tag.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetUserCertificateDetailRequest(DaraModel):
    def __init__(
        self,
        cert_filter: bool = None,
        cert_id: int = None,
    ):
        # Specifies whether to filter return results. Valid values: true and false. Default value: false. **true** specifies that the Cert, Key, EncryptCert, EncryptPrivateKey, SignCert, and SignPrivateKey parameters are not returned. **false** specifies that the parameters are returned.
        self.cert_filter = cert_filter
        # The ID of the certificate.
        # 
        # >  You can call the [ListUserCertificateOrder](https://help.aliyun.com/document_detail/455804.html) operation to query the ID.
        # 
        # This parameter is required.
        self.cert_id = cert_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_filter is not None:
            result['CertFilter'] = self.cert_filter

        if self.cert_id is not None:
            result['CertId'] = self.cert_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertFilter') is not None:
            self.cert_filter = m.get('CertFilter')

        if m.get('CertId') is not None:
            self.cert_id = m.get('CertId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeWarehouseCertResponseBody(DaraModel):
    def __init__(
        self,
        cert_identifier: str = None,
        cert_status: str = None,
        cert_type: str = None,
        common_name: str = None,
        content: str = None,
        fingerprint: str = None,
        issuer: str = None,
        issuer_identifier: str = None,
        private_ca_instance_id: str = None,
        private_ca_region_id: str = None,
        request_id: str = None,
        warehouse_instance_id: str = None,
    ):
        self.cert_identifier = cert_identifier
        self.cert_status = cert_status
        self.cert_type = cert_type
        self.common_name = common_name
        self.content = content
        self.fingerprint = fingerprint
        self.issuer = issuer
        self.issuer_identifier = issuer_identifier
        self.private_ca_instance_id = private_ca_instance_id
        self.private_ca_region_id = private_ca_region_id
        self.request_id = request_id
        self.warehouse_instance_id = warehouse_instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.cert_status is not None:
            result['CertStatus'] = self.cert_status

        if self.cert_type is not None:
            result['CertType'] = self.cert_type

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.content is not None:
            result['Content'] = self.content

        if self.fingerprint is not None:
            result['Fingerprint'] = self.fingerprint

        if self.issuer is not None:
            result['Issuer'] = self.issuer

        if self.issuer_identifier is not None:
            result['IssuerIdentifier'] = self.issuer_identifier

        if self.private_ca_instance_id is not None:
            result['PrivateCaInstanceId'] = self.private_ca_instance_id

        if self.private_ca_region_id is not None:
            result['PrivateCaRegionId'] = self.private_ca_region_id

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.warehouse_instance_id is not None:
            result['WarehouseInstanceId'] = self.warehouse_instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CertStatus') is not None:
            self.cert_status = m.get('CertStatus')

        if m.get('CertType') is not None:
            self.cert_type = m.get('CertType')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('Content') is not None:
            self.content = m.get('Content')

        if m.get('Fingerprint') is not None:
            self.fingerprint = m.get('Fingerprint')

        if m.get('Issuer') is not None:
            self.issuer = m.get('Issuer')

        if m.get('IssuerIdentifier') is not None:
            self.issuer_identifier = m.get('IssuerIdentifier')

        if m.get('PrivateCaInstanceId') is not None:
            self.private_ca_instance_id = m.get('PrivateCaInstanceId')

        if m.get('PrivateCaRegionId') is not None:
            self.private_ca_region_id = m.get('PrivateCaRegionId')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('WarehouseInstanceId') is not None:
            self.warehouse_instance_id = m.get('WarehouseInstanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateCsrRequest(DaraModel):
    def __init__(
        self,
        csr_id: int = None,
        key: str = None,
    ):
        # The ID of the CSR.
        # 
        # This parameter is required.
        self.csr_id = csr_id
        # The private key content of the certificate in the PEM format.
        # 
        # This parameter is required.
        self.key = key

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.csr_id is not None:
            result['CsrId'] = self.csr_id

        if self.key is not None:
            result['Key'] = self.key

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CsrId') is not None:
            self.csr_id = m.get('CsrId')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateCertificateWithCsrRequestResponseBody(DaraModel):
    def __init__(
        self,
        order_id: int = None,
        request_id: str = None,
    ):
        # The ID of the certificate application order.
        # 
        # >  You can use the ID to query the status of the certificate application. For more information, see [DescribeCertificateState](https://help.aliyun.com/document_detail/164111.html).
        self.order_id = order_id
        # The ID of the request, which is used to locate and troubleshoot issues.
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.order_id is not None:
            result['OrderId'] = self.order_id

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateWarehouseRequest(DaraModel):
    def __init__(
        self,
        biz: str = None,
        name: str = None,
        type: str = None,
    ):
        self.biz = biz
        self.name = name
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.biz is not None:
            result['Biz'] = self.biz

        if self.name is not None:
            result['Name'] = self.name

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Biz') is not None:
            self.biz = m.get('Biz')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateWHClientCertificateResponseBody(DaraModel):
    def __init__(
        self,
        certificate_chain: str = None,
        identifier: str = None,
        parent_x509certificate: str = None,
        request_id: str = None,
        root_x509certificate: str = None,
        x_509certificate: str = None,
    ):
        self.certificate_chain = certificate_chain
        self.identifier = identifier
        self.parent_x509certificate = parent_x509certificate
        self.request_id = request_id
        self.root_x509certificate = root_x509certificate
        self.x_509certificate = x_509certificate

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.certificate_chain is not None:
            result['CertificateChain'] = self.certificate_chain

        if self.identifier is not None:
            result['Identifier'] = self.identifier

        if self.parent_x509certificate is not None:
            result['ParentX509Certificate'] = self.parent_x509certificate

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.root_x509certificate is not None:
            result['RootX509Certificate'] = self.root_x509certificate

        if self.x_509certificate is not None:
            result['X509Certificate'] = self.x_509certificate

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertificateChain') is not None:
            self.certificate_chain = m.get('CertificateChain')

        if m.get('Identifier') is not None:
            self.identifier = m.get('Identifier')

        if m.get('ParentX509Certificate') is not None:
            self.parent_x509certificate = m.get('ParentX509Certificate')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('RootX509Certificate') is not None:
            self.root_x509certificate = m.get('RootX509Certificate')

        if m.get('X509Certificate') is not None:
            self.x_509certificate = m.get('X509Certificate')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListCloudAccessResponseBody(DaraModel):
    def __init__(
        self,
        cloud_access_list: List[main_models.ListCloudAccessResponseBodyCloudAccessList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        # The query results.
        self.cloud_access_list = cloud_access_list
        # The default value is the current page. If CurrentPage is not specified, this parameter is not returned.
        self.current_page = current_page
        # The request ID.
        self.request_id = request_id
        # The number of entries per page. If ShowSize is not specified, this parameter is not returned.
        self.show_size = show_size
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.cloud_access_list:
            for v1 in self.cloud_access_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['CloudAccessList'] = []
        if self.cloud_access_list is not None:
            for k1 in self.cloud_access_list:
                result['CloudAccessList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.cloud_access_list = []
        if m.get('CloudAccessList') is not None:
            for k1 in m.get('CloudAccessList'):
                temp_model = main_models.ListCloudAccessResponseBodyCloudAccessList()
                self.cloud_access_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListCloudAccessResponseBodyCloudAccessList(DaraModel):
    def __init__(
        self,
        access_id: int = None,
        cloud_name: str = None,
        secret_id: str = None,
        service_status: str = None,
    ):
        # The ID of the primary key.
        self.access_id = access_id
        # The cloud service provider.
        self.cloud_name = cloud_name
        # The AccessKey ID that is used to access cloud resources.
        self.secret_id = secret_id
        # The service status. The value normal indicates that the service runs as expected.
        self.service_status = service_status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_id is not None:
            result['AccessId'] = self.access_id

        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.secret_id is not None:
            result['SecretId'] = self.secret_id

        if self.service_status is not None:
            result['ServiceStatus'] = self.service_status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessId') is not None:
            self.access_id = m.get('AccessId')

        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('SecretId') is not None:
            self.secret_id = m.get('SecretId')

        if m.get('ServiceStatus') is not None:
            self.service_status = m.get('ServiceStatus')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class GetUserCertificateDetailResponseBody(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        buy_in_aliyun: bool = None,
        cert: str = None,
        cert_chain: List[main_models.GetUserCertificateDetailResponseBodyCertChain] = None,
        cert_identifier: str = None,
        city: str = None,
        common: str = None,
        country: str = None,
        encrypt_cert: str = None,
        encrypt_private_key: str = None,
        end_date: str = None,
        expired: bool = None,
        fingerprint: str = None,
        id: int = None,
        instance_id: str = None,
        issuer: str = None,
        key: str = None,
        name: str = None,
        not_after: int = None,
        not_before: int = None,
        order_id: int = None,
        org_name: str = None,
        province: str = None,
        request_id: str = None,
        resource_group_id: str = None,
        sans: str = None,
        serial_no: str = None,
        sha_2: str = None,
        sign_cert: str = None,
        sign_private_key: str = None,
        start_date: str = None,
        tags: List[main_models.GetUserCertificateDetailResponseBodyTags] = None,
    ):
        # The algorithm.
        self.algorithm = algorithm
        # Indicates whether the certificate was purchased from Alibaba Cloud. Valid values:
        # 
        # *   **true**: yes
        # *   **false**: no
        self.buy_in_aliyun = buy_in_aliyun
        # The content of the certificate if the certificate does not use an SM algorithm. If certFilter is set to false, this parameter is returned. Otherwise, this parameter is not returned.
        self.cert = cert
        # The certificate chain.
        self.cert_chain = cert_chain
        # The certificate identifier. The value is in the "Certificate ID-cn-hangzhou" format. For example, if the ID of the certificate is 123, the value of CertIdentifier is 123-cn-hangzhou.
        self.cert_identifier = cert_identifier
        # The city of the company or organization to which the certificate purchaser belongs.
        self.city = city
        # The primary domain name that is bound to the certificate.
        self.common = common
        # The country or region of the company or organization to which the certificate purchaser belongs.
        self.country = country
        # The content of the encryption certificate if the certificate uses an SM algorithm and is encoded in the PEM format. If certFilter is set to false, this parameter is returned. Otherwise, this parameter is not returned.
        self.encrypt_cert = encrypt_cert
        # The private key of the encryption certificate if the certificate uses an SM algorithm and is encoded in the PEM format. If certFilter is set to false, this parameter is returned. Otherwise, this parameter is not returned.
        self.encrypt_private_key = encrypt_private_key
        # The expiration date of the certificate.
        self.end_date = end_date
        # Indicates whether the certificate has expired. Valid values:
        # 
        # *   **true**: yes
        # *   **false**: no
        self.expired = expired
        # The fingerprint of the certificate.
        self.fingerprint = fingerprint
        # The ID of the certificate.
        self.id = id
        # The instance ID of the resource.
        self.instance_id = instance_id
        # The certificate authority (CA) that issued the certificate.
        self.issuer = issuer
        # The private key of the certificate if the certificate does not use an SM algorithm. If certFilter is set to false, this parameter is returned. Otherwise, this parameter is not returned.
        self.key = key
        # The name of the certificate.
        self.name = name
        # The end of the validity period of the certificate.
        self.not_after = not_after
        # The beginning of the validity period of the certificate.
        self.not_before = not_before
        # The order ID.
        self.order_id = order_id
        # The name of the company or organization to which the certificate purchaser belongs.
        self.org_name = org_name
        # The province of the company or organization to which the certificate purchaser belongs.
        self.province = province
        # The ID of the request, which is used to locate and troubleshoot issues.
        self.request_id = request_id
        # The ID of the resource group.
        self.resource_group_id = resource_group_id
        # All domain names that are bound to the certificate.
        self.sans = sans
        # The serial number of the certificate.
        self.serial_no = serial_no
        # The SHA-2 value of the certificate.
        self.sha_2 = sha_2
        # The content of the signing certificate if the certificate uses an SM algorithm and is encoded in the PEM format. If certFilter is set to false, this parameter is returned. Otherwise, this parameter is not returned.
        self.sign_cert = sign_cert
        # The private key of the signing certificate if the certificate uses an SM algorithm and is encoded in the PEM format. If certFilter is set to false, this parameter is returned. Otherwise, this parameter is not returned.
        self.sign_private_key = sign_private_key
        # The issuance date of the certificate.
        self.start_date = start_date
        self.tags = tags

    def validate(self):
        if self.cert_chain:
            for v1 in self.cert_chain:
                 if v1:
                    v1.validate()
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.buy_in_aliyun is not None:
            result['BuyInAliyun'] = self.buy_in_aliyun

        if self.cert is not None:
            result['Cert'] = self.cert

        result['CertChain'] = []
        if self.cert_chain is not None:
            for k1 in self.cert_chain:
                result['CertChain'].append(k1.to_map() if k1 else None)

        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.city is not None:
            result['City'] = self.city

        if self.common is not None:
            result['Common'] = self.common

        if self.country is not None:
            result['Country'] = self.country

        if self.encrypt_cert is not None:
            result['EncryptCert'] = self.encrypt_cert

        if self.encrypt_private_key is not None:
            result['EncryptPrivateKey'] = self.encrypt_private_key

        if self.end_date is not None:
            result['EndDate'] = self.end_date

        if self.expired is not None:
            result['Expired'] = self.expired

        if self.fingerprint is not None:
            result['Fingerprint'] = self.fingerprint

        if self.id is not None:
            result['Id'] = self.id

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.issuer is not None:
            result['Issuer'] = self.issuer

        if self.key is not None:
            result['Key'] = self.key

        if self.name is not None:
            result['Name'] = self.name

        if self.not_after is not None:
            result['NotAfter'] = self.not_after

        if self.not_before is not None:
            result['NotBefore'] = self.not_before

        if self.order_id is not None:
            result['OrderId'] = self.order_id

        if self.org_name is not None:
            result['OrgName'] = self.org_name

        if self.province is not None:
            result['Province'] = self.province

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.sans is not None:
            result['Sans'] = self.sans

        if self.serial_no is not None:
            result['SerialNo'] = self.serial_no

        if self.sha_2 is not None:
            result['Sha2'] = self.sha_2

        if self.sign_cert is not None:
            result['SignCert'] = self.sign_cert

        if self.sign_private_key is not None:
            result['SignPrivateKey'] = self.sign_private_key

        if self.start_date is not None:
            result['StartDate'] = self.start_date

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('BuyInAliyun') is not None:
            self.buy_in_aliyun = m.get('BuyInAliyun')

        if m.get('Cert') is not None:
            self.cert = m.get('Cert')

        self.cert_chain = []
        if m.get('CertChain') is not None:
            for k1 in m.get('CertChain'):
                temp_model = main_models.GetUserCertificateDetailResponseBodyCertChain()
                self.cert_chain.append(temp_model.from_map(k1))

        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('City') is not None:
            self.city = m.get('City')

        if m.get('Common') is not None:
            self.common = m.get('Common')

        if m.get('Country') is not None:
            self.country = m.get('Country')

        if m.get('EncryptCert') is not None:
            self.encrypt_cert = m.get('EncryptCert')

        if m.get('EncryptPrivateKey') is not None:
            self.encrypt_private_key = m.get('EncryptPrivateKey')

        if m.get('EndDate') is not None:
            self.end_date = m.get('EndDate')

        if m.get('Expired') is not None:
            self.expired = m.get('Expired')

        if m.get('Fingerprint') is not None:
            self.fingerprint = m.get('Fingerprint')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Issuer') is not None:
            self.issuer = m.get('Issuer')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('NotAfter') is not None:
            self.not_after = m.get('NotAfter')

        if m.get('NotBefore') is not None:
            self.not_before = m.get('NotBefore')

        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        if m.get('OrgName') is not None:
            self.org_name = m.get('OrgName')

        if m.get('Province') is not None:
            self.province = m.get('Province')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('Sans') is not None:
            self.sans = m.get('Sans')

        if m.get('SerialNo') is not None:
            self.serial_no = m.get('SerialNo')

        if m.get('Sha2') is not None:
            self.sha_2 = m.get('Sha2')

        if m.get('SignCert') is not None:
            self.sign_cert = m.get('SignCert')

        if m.get('SignPrivateKey') is not None:
            self.sign_private_key = m.get('SignPrivateKey')

        if m.get('StartDate') is not None:
            self.start_date = m.get('StartDate')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.GetUserCertificateDetailResponseBodyTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class GetUserCertificateDetailResponseBodyTags(DaraModel):
    def __init__(
        self,
        tag_key: str = None,
        tag_value: str = None,
    ):
        self.tag_key = tag_key
        self.tag_value = tag_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.tag_key is not None:
            result['TagKey'] = self.tag_key

        if self.tag_value is not None:
            result['TagValue'] = self.tag_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('TagKey') is not None:
            self.tag_key = m.get('TagKey')

        if m.get('TagValue') is not None:
            self.tag_value = m.get('TagValue')

        return self

class GetUserCertificateDetailResponseBodyCertChain(DaraModel):
    def __init__(
        self,
        common_name: str = None,
        issuer_common_name: str = None,
        not_after: int = None,
        not_before: int = None,
        remain_day: int = None,
    ):
        # The common name of the certificate.
        self.common_name = common_name
        # The common name of the issuer.
        self.issuer_common_name = issuer_common_name
        # The end of the validity period of the certificate.
        self.not_after = not_after
        # The beginning of the validity period of the certificate.
        self.not_before = not_before
        # The remaining days of the certificate validity period.
        self.remain_day = remain_day

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.issuer_common_name is not None:
            result['IssuerCommonName'] = self.issuer_common_name

        if self.not_after is not None:
            result['NotAfter'] = self.not_after

        if self.not_before is not None:
            result['NotBefore'] = self.not_before

        if self.remain_day is not None:
            result['RemainDay'] = self.remain_day

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('IssuerCommonName') is not None:
            self.issuer_common_name = m.get('IssuerCommonName')

        if m.get('NotAfter') is not None:
            self.not_after = m.get('NotAfter')

        if m.get('NotBefore') is not None:
            self.not_before = m.get('NotBefore')

        if m.get('RemainDay') is not None:
            self.remain_day = m.get('RemainDay')

        return self

